#!/bin/bash

OPENAISROOT=/opt/openais-trunk
TESTROOT=/opt/aisrobustness
LOGDIR=$TESTROOT/typeSpecificTests/bin/log

# set main config file
export OPENAIS_MAIN_CONFIG_FILE=$TESTROOT/conf/aisrobustness_openais.conf

# set host name in AMF file
HOSTNAME=$(hostname)
sed s/%HOSTNAME%/$HOSTNAME/g conf/aisrobustness_openais_amf.conf > tmpfile
mv tmpfile conf/aisrobustness_openais_amf.conf

# start test cases
echo "<runs>"
echo	"<date>"
date
echo	"</date>"

for TESTCASE in typeSpecificTests/bin/test_*
do
	TESTCASE_NAME=$(echo $TESTCASE | cut -d/ -f3)
	echo "<run>"
	echo 	"<testName>$TESTCASE_NAME</testName>"

	# create config file
	cp conf/aisrobustness_openais_amf.conf "conf/aisrobustness_openais_amf_$TESTCASE_NAME.conf"
	sed s/%TEST_CASE_NAME%/$TESTCASE_NAME/g "conf/aisrobustness_openais_amf_$TESTCASE_NAME.conf" > tmpfile
	mv tmpfile "conf/aisrobustness_openais_amf_$TESTCASE_NAME.conf"

	export OPENAIS_AMF_CONFIG_FILE=$TESTROOT/conf/aisrobustness_openais_amf_$TESTCASE_NAME.conf

	echo 	"<output>"	

	# start middleware
	AISLOGNAME="ais-$TESTCASE_NAME-$(date +%Y.%m.%d_%H.%M.%S).log"
	cd $OPENAISROOT/exec
	./aisexec 2> $LOGDIR/$AISLOGNAME &

	# wait until calls are finished
	while [ ! -e finished ]; do
		sleep 10
	done
	rm finished

	echo 	"</output>"	

	# stop middleware
	echo	"<killAll>"
	killall aisexec
	echo	"</killAll>"

	cd $TESTROOT

	echo "</run>"
done

echo "</runs>"
